-- progress.lua

local Params = ...
local M = Params.M
local F = far.Flags

local DELAY = 150 -- in milliseconds; to avoid flickering

local uchar1 = unicode.utf8.char(9608)
local uchar2 = unicode.utf8.char(9617)
local PROGRESS_WIDTH = 30

local progress = {}
local mt_progress = { __index=progress }

function progress.newprogress(msg, max_value)
  local self = setmetatable({}, mt_progress)
  self._visible = false
  self._max_value = max_value or 0
  self._title = M.ps_title_short
  self._message = msg
  self._start = far.FarClock()
  return self
end


function progress:show()
  if not self._visible then
    self._visible = true
    far.AdvControl("ACTL_SETPROGRESSSTATE", "TBPS_INDETERMINATE")
  end

  if self._bar == nil then
    far.Message(self._message, self._title, "")
  else
    far.Message(self._message.."\n"..self._bar, self._title, "")
  end
end


function progress:hide()
  if self._visible then
    far.AdvControl("ACTL_PROGRESSNOTIFY")
    far.AdvControl("ACTL_SETPROGRESSSTATE", "TBPS_NOPROGRESS")
    panel.RedrawPanel(nil, 1)
    panel.RedrawPanel(nil, 0)
    self._visible = false
  end
end


function progress:update(val)
  if self._max_value == 0 then return; end

  if (far.FarClock() - self._start) < DELAY*1000 then return; end

  local percent = math.floor(val * 100 / self._max_value)

  local pv = { Completed=percent; Total=100 }
  far.AdvControl("ACTL_SETPROGRESSVALUE", 0, pv)

  local len = math.floor(percent * PROGRESS_WIDTH / 100)
  self._bar = uchar1:rep(len) .. uchar2:rep(PROGRESS_WIDTH - len)

  self:show()
end


function progress.aborted() -- function, not method
  return win.ExtractKey() == "ESCAPE"
end


return progress
